pub struct DesktopNames {
pub programs: HashMap<String, String>,
pub dirs: HashMap<PathBuf, String>,
}Expand description
Installed application names, from the desktop entries.
Fields
programs: HashMap<String, String>By the basename of the program an entry’s Exec runs (firefox to
Firefox). See [names_from_entries].
dirs: HashMap<PathBuf, String>By the directory an app is installed in (/opt/google/chrome to
Google Chrome), for a process whose program no entry runs by name.
See [dirs_from_entries].