Module exit

Module exit 

How a command launched under limits ended, shared by the CLI and GUI.

Functions

exit_report
(exit code for the caller, messages without a “rlm:” prefix)
signal_name
The conventional name of a signal number, or a generic description.