find_process_tree

Function find_process_tree 

pub fn find_process_tree(root_pid: u32) -> Result<Vec<u32>>
Find all processes that share the same parent process tree Returns processes that are descendants of the given PID