start_time

Function start_time 

pub fn start_time(pid: u32) -> Option<u64>
When pid started, or None if it is gone. With the PID it names one process: a PID reused later by another process has a different start time.