pub fn exec_program(value: &str) -> Option<String>
The basename of the program a raw desktop file Exec value runs, looking past an env VAR=value wrapper. None if there is none.
Exec
env VAR=value
None