How a command launched under limits ended, shared by the CLI and GUI.
Functions
- exit_
report - (exit code for the caller, messages without a “rlm:” prefix)
- signal_
name - The conventional name of a signal number, or a generic description.